==> apache-geode-1.14.4-src.tgz: apache-geode-1.14.4-src/geode-core/src/distributedTest/java/org/apache/geode/disttx/CacheMapDistTXDUnitTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more contributor license
 * agreements. See the NOTICE file distributed with this work for additional information regarding
 * copyright ownership. The ASF licenses this file to You under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
package org.apache.geode.disttx;

import static org.apache.geode.distributed.ConfigurationProperties.DISTRIBUTED_TRANSACTIONS;
import static org.junit.Assert.assertTrue;

import org.junit.Test;

import org.apache.geode.cache30.CacheMapTxnDUnitTest;
import org.apache.geode.test.dunit.Host;
import org.apache.geode.test.dunit.VM;


/**
 * Same tests as that of {@link CacheMapTxnDUnitTest} after setting "distributed-transactions"
 * property to true
 */

public class CacheMapDistTXDUnitTest extends CacheMapTxnDUnitTest {

  public CacheMapDistTXDUnitTest() {
    super();
  }

  @Override
  public final void preSetUp() throws Exception {
    Host host = Host.getHost(0);
    VM vm0 = host.getVM(0);
    VM vm1 = host.getVM(1);

    vm0.invoke(() -> CacheMapDistTXDUnitTest.setDistributedTX());
    vm1.invoke(() -> CacheMapDistTXDUnitTest.setDistributedTX());
  }

  @Override
  public final void postSetUpCacheMapTxnDUnitTest() throws Exception {
    Host host = Host.getHost(0);
    VM vm0 = host.getVM(0);
    VM vm1 = host.getVM(1);

    // make sure that "distributed-transactions" is true
    vm0.invoke(() -> CacheMapDistTXDUnitTest.checkIsDistributedTX());
    vm1.invoke(() -> CacheMapDistTXDUnitTest.checkIsDistributedTX());
  }

  @Override
  public final void postTearDown() throws Exception {
    props.clear();
  }

  public static void setDistributedTX() {
    props.setProperty(DISTRIBUTED_TRANSACTIONS, "true");
  }

  public static void checkIsDistributedTX() {
    assertTrue(cache.getCacheTransactionManager().isDistributed());
  }

  @Override
  @Test
  public void testCommitTxn() {
    // [DISTTX] TODO test overridden intentionally and left blank as it fails
    // fix this
  }

}

==> apache-geode-1.15.2-src.tgz: apache-geode-1.15.2-src/geode-core/src/distributedTest/java/org/apache/geode/disttx/CacheMapDistTXDUnitTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more contributor license
 * agreements. See the NOTICE file distributed with this work for additional information regarding
 * copyright ownership. The ASF licenses this file to You under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
package org.apache.geode.disttx;

import static org.apache.geode.distributed.ConfigurationProperties.DISTRIBUTED_TRANSACTIONS;
import static org.junit.Assert.assertTrue;

import org.junit.Test;

import org.apache.geode.cache30.CacheMapTxnDUnitTest;
import org.apache.geode.test.dunit.Host;
import org.apache.geode.test.dunit.VM;


/**
 * Same tests as that of {@link CacheMapTxnDUnitTest} after setting "distributed-transactions"
 * property to true
 */

public class CacheMapDistTXDUnitTest extends CacheMapTxnDUnitTest {

  public CacheMapDistTXDUnitTest() {
    super();
  }

  @Override
  public final void preSetUp() throws Exception {
    Host host = Host.getHost(0);
    VM vm0 = host.getVM(0);
    VM vm1 = host.getVM(1);

    vm0.invoke(CacheMapDistTXDUnitTest::setDistributedTX);
    vm1.invoke(CacheMapDistTXDUnitTest::setDistributedTX);
  }

  @Override
  public final void postSetUpCacheMapTxnDUnitTest() throws Exception {
    Host host = Host.getHost(0);
    VM vm0 = host.getVM(0);
    VM vm1 = host.getVM(1);

    // make sure that "distributed-transactions" is true
    vm0.invoke(CacheMapDistTXDUnitTest::checkIsDistributedTX);
    vm1.invoke(CacheMapDistTXDUnitTest::checkIsDistributedTX);
  }

  @Override
  public final void postTearDown() throws Exception {
    props.clear();
  }

  public static void setDistributedTX() {
    props.setProperty(DISTRIBUTED_TRANSACTIONS, "true");
  }

  public static void checkIsDistributedTX() {
    assertTrue(cache.getCacheTransactionManager().isDistributed());
  }

  @Override
  @Test
  public void testCommitTxn() {
    // [DISTTX] TODO test overridden intentionally and left blank as it fails
    // fix this
  }

}
